# Generated by Django 2.0.7 on 2018-07-18 08:28

from django.db import migrations, models
import django.db.models.deletion
import stdimage.models


class Migration(migrations.Migration):

    dependencies = [
        ('nuntius', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='MosaicoImage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('file', stdimage.models.StdImageField(upload_to='mosaico')),
                ('created', models.DateTimeField(auto_now_add=True)),
            ],
        ),
        migrations.AddField(
            model_name='campaign',
            name='message_mosaico_data',
            field=models.TextField(blank=True, verbose_name='Mosaico data'),
        )
    ]
